%%
close all
clear all
%%

load('H1LT_0deg.mat')
load('H1LT_ANGLE.mat')
load('H2LT_0deg.mat')
load('H2LT_ANGLE.mat')

load('Sysid_Cf_exp_v3.mat')
load('Sysid_Cd_exp_v3.mat')

%%
%%
set(groot,'defaulttextInterpreter','latex');
set(groot, 'defaultAxesTickLabelInterpreter','latex');
set(groot,'defaultLegendInterpreter','latex');
f = 0;
%%
rho = 1000;
a = 0.05;
b = 0.045;
l = 0.09;
HODEA = 0.005919;
HALEA = 0.004757;
Ct = 0.5*rho*pi*((a+b)/2)*2*l;
Cn = 0.5*rho*2*a*2*l;

%% Fx
Fxhh1 = @(Vx,Cfhh1) -0.5*pi*rho*a*b*Vx*Cfhh1;
Fxhh2 = @(Vx,Cfhh2) -0.5*sign(Vx)*pi*rho*a*b*Vx^2*Cfhh2;
Fxl1 = @(Vx,Cfl1,N) -Ct*Vx*Cfl1*N;
Fxl2 = @(Vx,Cfl2,N) sign(Vx)*Ct*Vx^2*Cfl2*N;
Fxy1 = @(Vy,Cfxy1) -sign(Vy)*0.5*Cn*Vy*Cfxy1;
Fxy2 = @(Vy,Cfxy2) 0.5*Cn*Vy^2*Cfxy2;
FX = @(Vx,Vy,Cfhh1,Cfhh2,Cfl1,Cfl2,Cfxy1,Cfxy2,N) Fxhh1(Vx,Cfhh1)+Fxhh2(Vx,Cfhh2)+Fxl1(Vx,Cfl1,N)+Fxl2(Vx,Cfl2,N)+Fxy1(Vy,Cfxy1)+Fxy2(Vy,Cfxy2);
%FX = @(Vx,Vy,Cfhh1,Cfhh2,Cfl1,Cfl2,Cfxy1,Cfxy2,N) Fxhh1(Vx,Cfhh1)+Fxhh2(Vx,Cfhh2)+Fxl1(Vx,Cfl1,N)+Fxl2(Vx,Cfl2,N)+Fxy1(Vy,Cfxy1)+Fxy2(Vy,Cfxy2);

%% Fy
Fyhh1 = @(Vy,Cdhh1) -0.5*rho*(HODEA+HALEA)*Vy*Cdhh1;
Fyhh2 = @(Vy,Cdhh2) -sign(Vy)*0.5*rho*(HODEA+HALEA)*Vy^2*Cdhh2;
Fyl1 = @(Vy,Cdl1,N) -Cn*Vy*Cdl1*N;
Fyl2 = @(Vy,Cdl2,N) -sign(Vy)*Cn*Vy^2*Cdl2*N;

FY = @(Vy,Cdhh1,Cdhh2,Cdl1,Cdl2,N) Fyhh1(Vy,Cdhh1)+Fyhh2(Vy,Cdhh2)+Fyl1(Vy,Cdl1,N)+Fyl2(Vy,Cdl2,N);

%% HnLT 0deg
Teox_h1lt = zeros(1000,1);
Teox_h1lt_nn = zeros(1000,1);
Teox_h2lt = zeros(1000,1);
Teox_h2lt_nn = zeros(1000,1);

V = zeros(1000,1);
for i = 1:1000
    V(i) = i/1000;
    Teox_h1lt(i) = FX(V(i),0,Param_Cf_exp_v3(1,1),Param_Cf_exp_v3(2,1),Param_Cf_exp_v3(3,1),Param_Cf_exp_v3(4,1),Param_Cf_exp_v3(5,1),Param_Cf_exp_v3(6,1),1);
    Teox_h1lt_nn(i) = FX(V(i),0,Param_Cf_exp_v3(1,2),Param_Cf_exp_v3(2,2),Param_Cf_exp_v3(3,2),Param_Cf_exp_v3(4,2),Param_Cf_exp_v3(5,2),Param_Cf_exp_v3(6,2),1);
    Teox_h2lt(i) = FX(V(i),0,Param_Cf_exp_v3(1,1),Param_Cf_exp_v3(2,1),Param_Cf_exp_v3(3,1),Param_Cf_exp_v3(4,1),Param_Cf_exp_v3(5,1),Param_Cf_exp_v3(6,1),2);
    Teox_h2lt_nn(i) = FX(V(i),0,Param_Cf_exp_v3(1,2),Param_Cf_exp_v3(2,2),Param_Cf_exp_v3(3,2),Param_Cf_exp_v3(4,2),Param_Cf_exp_v3(5,2),Param_Cf_exp_v3(6,2),2);
end
%% plot 0deg

load('..\..\Simulations_master\v3\H1LT_sim_v3.mat')
load('..\..\Simulations_master\v3\H2LT_sim_v3.mat')

f = f+1;
figure(f)
title('Experimental results versus estimation')
subplot(2,1,1)
title('H1LT')
xlabel('Velocity X [m/s]')
ylabel('Force X [N]')
hold on
grid on
plot(V,Teox_h1lt)
plot(V,Teox_h1lt_nn)
plot(H1LT_sim_v3(1:50,2),H1LT_sim_v3(1:50,4),'--')
plot(H1LT_0deg(:,2),H1LT_0deg(:,1),'rx','linewidth',1.5)
legend('Estimated model','Estimated model - non-negative','Simulation','Experimental results','location','best')

subplot(2,1,2)
 title('H2LT')
 xlabel('Velocity X [m/s]')
 ylabel('Force X [N]')
hold on
grid on
plot(V,Teox_h2lt)
plot(V,Teox_h2lt_nn)
plot(H2LT_sim_v3(1:50,2),H2LT_sim_v3(1:50,4),'--')
plot(H2LT_0deg(:,2),H2LT_0deg(:,1),'rx','linewidth',1.5)
legend('Estimated model','Estimated model - non-negative','Simulation','Experimental results','location','best')
print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\experiments\exp_result_0deg.eps');
%% HnLT ANGLE
Teox_angle_h1lt = zeros(39,1);
Teox_angle_h1lt_nn = zeros(39,1);
Teox_angle_h2lt = zeros(39,1);
Teox_angle_h2lt_nn = zeros(39,1);
Teoy_angle_h1lt = zeros(39,1);
Teoy_angle_h1lt_nn = zeros(39,1);
Teoy_angle_h2lt = zeros(39,1);
Teoy_angle_h2lt_nn = zeros(39,1);
Angle = 3:3:39;
for i = 1:39
    Teox_angle_h1lt(i) = FX(H1LT_ANGLE(i,5),H1LT_ANGLE(i,11),Param_Cf_exp_v3(1,1),Param_Cf_exp_v3(2,1),Param_Cf_exp_v3(3,1),Param_Cf_exp_v3(4,1),Param_Cf_exp_v3(5,1),Param_Cf_exp_v3(6,1),1);
    Teox_angle_h1lt_nn(i) = FX(H1LT_ANGLE(i,5),H1LT_ANGLE(i,11),Param_Cf_exp_v3(1,2),Param_Cf_exp_v3(2,2),Param_Cf_exp_v3(3,2),Param_Cf_exp_v3(4,2),Param_Cf_exp_v3(5,2),Param_Cf_exp_v3(6,2),1);
    Teox_angle_h2lt(i) = FX(H2LT_ANGLE(i,5),H2LT_ANGLE(i,11),Param_Cf_exp_v3(1,1),Param_Cf_exp_v3(2,1),Param_Cf_exp_v3(3,1),Param_Cf_exp_v3(4,1),Param_Cf_exp_v3(5,1),Param_Cf_exp_v3(6,1),2);
    Teox_angle_h2lt_nn(i) = FX(H2LT_ANGLE(i,5),H2LT_ANGLE(i,11),Param_Cf_exp_v3(1,2),Param_Cf_exp_v3(2,2),Param_Cf_exp_v3(3,2),Param_Cf_exp_v3(4,2),Param_Cf_exp_v3(5,2),Param_Cf_exp_v3(6,2),2);
    Teoy_angle_h1lt(i) = FY(H1LT_ANGLE(i,11),Param_Cd_exp_v3(1,1),Param_Cd_exp_v3(2,1),Param_Cd_exp_v3(3,1),Param_Cd_exp_v3(4,1),1);
    Teoy_angle_h1lt_nn(i) = FY(H1LT_ANGLE(i,11),Param_Cd_exp_v3(1,2),Param_Cd_exp_v3(2,2),Param_Cd_exp_v3(3,2),Param_Cd_exp_v3(4,2),1);
    Teoy_angle_h2lt(i) = FY(H2LT_ANGLE(i,11),Param_Cd_exp_v3(1,1),Param_Cd_exp_v3(2,1),Param_Cd_exp_v3(3,1),Param_Cd_exp_v3(4,1),2);
    Teoy_angle_h2lt_nn(i) = FY(H2LT_ANGLE(i,11),Param_Cd_exp_v3(1,2),Param_Cd_exp_v3(2,2),Param_Cd_exp_v3(3,2),Param_Cd_exp_v3(4,2),2);
end
%% Plots angle
f = f+1;
figure(f)
set(f, 'Position', [0, 0, 1049, 895]);
subplot(2,2,1)
title('H1LT')
hold on
grid on
ylabel('Force X [N]')
xlabel('Angle [$^\circ$]')
plot(Angle,H1LT_ANGLE(1:13,3),'x')
plot(Angle,Teox_angle_h1lt(1:13))
plot(Angle,H1LT_ANGLE(14:26,3),'x')
plot(Angle,Teox_angle_h1lt(14:26))
plot(Angle,H1LT_ANGLE(27:39,3),'x')
plot(Angle,Teox_angle_h1lt(27:39))
legend('Experiment 50g','Model 50g','Experiment 75g','Model 75g','Experiment 100g','Model 100g','location','best')
subplot(2,2,2)
title('H2LT')
hold on
grid on
ylabel('Force X [N]')
xlabel('Angle [$^\circ$]')
plot(Angle,H2LT_ANGLE(1:13,3),'x')
plot(Angle,Teox_angle_h2lt(1:13))
plot(Angle,H2LT_ANGLE(14:26,3),'x')
plot(Angle,Teox_angle_h2lt(14:26))
plot(Angle,H2LT_ANGLE(27:39,3),'x')
plot(Angle,Teox_angle_h2lt(27:39))
legend('Experiment 50g','Model 50g','Experiment 75g','Model 75g','Experiment 100g','Model 100g','location','best')
subplot(2,2,3)
title('H1LT')
hold on
grid on
ylabel('Force Y [N]')
xlabel('Angle [$^\circ$]')
plot(Angle,H1LT_ANGLE(1:13,9),'x')
plot(Angle,Teoy_angle_h1lt(1:13))
plot(Angle,H1LT_ANGLE(14:26,9),'x')
plot(Angle,Teoy_angle_h1lt(14:26))
plot(Angle,H1LT_ANGLE(27:39,9),'x')
plot(Angle,Teoy_angle_h1lt(27:39))
legend('Experiment 50g','Model 50g','Experiment 75g','Model 75g','Experiment 100g','Model 100g','location','best')

subplot(2,2,4)
title('H2LT')
hold on
grid on
ylabel('Force Y [N]')
xlabel('Angle [$^\circ$]')
plot(Angle,H2LT_ANGLE(1:13,9),'x')
plot(Angle,Teoy_angle_h2lt(1:13))
plot(Angle,H2LT_ANGLE(14:26,9),'x')
plot(Angle,Teoy_angle_h2lt(14:26))
plot(Angle,H2LT_ANGLE(27:39,9),'x')
plot(Angle,Teoy_angle_h2lt(27:39))
legend('Experiment 50g','Model 50g','Experiment 75g','Model 75g','Experiment 100g','Model 100g','location','best')

print(figure(f),'-depsc2','..\..\..\..\Apps\ShareLaTeX\SNEK_MASTER2017\figures\experiments\exp_result_angle.eps');